use eframe::egui::{self, Response, Ui, Widget};

use super::state::AppState;

pub struct ModelSelection<'a> {
    app_state: &'a mut AppState,
    pub models_available: Vec<String>,
}

impl<'a> ModelSelection<'a> {
    pub fn new(app_state: &'a mut AppState, models_available: Vec<String>) -> Self {
        Self {
            app_state,
            models_available,
        }
    }
}

impl<'a> Widget for ModelSelection<'a> {
    fn ui(self, ui: &mut Ui) -> Response {
        ui.horizontal(|ui| {
            egui::ComboBox::from_label("")
                .selected_text("Models")
                .show_ui(ui, |ui| {
                    for model in self.models_available {
                        let contained = self.app_state.model_selection.contains(&model);

                        let label = ui.selectable_label(contained, &model);

                        if label.clicked() && !contained {
                            self.app_state.model_selection.push(model.clone());
                        }
                    }
                });

            let mut model_to_remove: Option<String> = None;

            for model in &self.app_state.model_selection {
                egui::Frame::none()
                    .inner_margin(8.0)
                    .rounding(4.0)
                    .fill(egui::Color32::WHITE)
                    .show(ui, |ui| {
                        ui.horizontal(|ui| {
                            ui.label(model);
                            if ui.button("X").clicked() {
                                model_to_remove.replace(model.clone());
                            }
                        });
                    });
            }

            if let Some(model) = model_to_remove {
                self.app_state.model_selection.retain(|m| m != &model);
            }
        })
        .response
    }
}
